@@ -6,6 +6,7 @@ from .. import __version__ as LIBRARY_VERSION
 from .resources import (
     make_request,
     Accounts,
+    Addresses,
     Applications,
     AuthorizedConnectApps,
     CallerIds,
@@ -13,6 +14,7 @@ from .resources import (
     Conferences,
     ConnectApps,
     Connection,
+    DependentPhoneNumbers,
     MediaList,
     Members,
     Messages,
@@ -29,6 +31,7 @@ from .resources import (
     Usage,
     CallFeedbackFactory,
     CallFeedback,
+    Tokens,
 )
 
 
@@ -94,6 +97,7 @@ values from your Twilio Account at https://www.twilio.com/user/account.
         account_uri = "%s/%s/Accounts/%s" % (base, version, account)
 
         self.accounts = Accounts(version_uri, auth, timeout)
+        self.addresses = Addresses(account_uri, auth, timeout)
         self.applications = Applications(account_uri, auth, timeout)
         self.authorized_connect_apps = AuthorizedConnectApps(
             account_uri,
@@ -115,6 +119,7 @@ values from your Twilio Account at https://www.twilio.com/user/account.
         self.messages = Messages(account_uri, auth, timeout)
         self.media = MediaList(account_uri, auth, timeout)
         self.sip = Sip(account_uri, auth, timeout)
+        self.tokens = Tokens(account_uri, auth, timeout)
 
         self.auth = auth
         self.account_uri = account_uri
@@ -151,6 +156,16 @@ values from your Twilio Account at https://www.twilio.com/user/account.
         )
         return CallFeedback(call_feedback_list)
 
+    def dependent_phone_numbers(self, address_sid):
+        """
+        Return a :class:`DependentPhoneNumbers
+        <twilio.rest.resources.DependentPhoneNumbers>` instance for the
+        :class:`Address <twilio.rest.resources.Address>` with the given
+        address_sid
+        """
+        base_uri = "%s/Addresses/%s" % (self.account_uri, address_sid)
+        return DependentPhoneNumbers(base_uri, self.auth, self.timeout)
+
     def request(self, path, method=None, vars=None):
         """sends a request and gets a response from the Twilio REST API
 
